'use strict';

Object.defineProperty(exports, '__esModule', {
	value: true
});
exports['default'] = getAnimationProperties;

var _getVendorPrefix = require('./get-vendor-prefix');

var propertyNames = ['name', 'duration', 'iterationCount', 'timingFunction', 'fillMode', 'playState'];

/**
 * Returns applicable animation properties for a given node
 * @param  {Node} node Node to read animation properties from
 * @param  {Window} window  Global context to use
 * @return {Object}         Applicable animation properties for node in window
 * @private
 */

function getAnimationProperties(node) {
	var window = arguments.length <= 1 || arguments[1] === undefined ? global.window : arguments[1];
	var document = arguments.length <= 2 || arguments[2] === undefined ? global.document : arguments[2];

	var styles = window.getComputedStyle(node);

	return propertyNames.reduce(function (properties, propertyName) {
		var cssName = 'animation' + propertyName[0].toUpperCase() + propertyName.slice(1);
		properties[propertyName] = styles[(0, _getVendorPrefix.prefix)(cssName, window, document)];
		return properties;
	}, {});
}

module.exports = exports['default'];