'use strict';

Object.defineProperty(exports, '__esModule', {
	value: true
});
exports['default'] = getDeclarations;
// istanbul ignore next

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

// istanbul ignore next

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) arr2[i] = arr[i]; return arr2; } else { return Array.from(arr); } }

var _cssruleEnumerations = require('./cssrule-enumerations');

var _cssruleEnumerations2 = _interopRequireDefault(_cssruleEnumerations);

var _toArray = require('./to-array');

var _toArray2 = _interopRequireDefault(_toArray);

/**
 * Gets all CSSRules of type typeName and matching the predecate from rules
 * @param  {string} [typeName='style']    - CSSRule type to search for, valid types:
 *                                          unknown, style, charset, import, media, fontface, page, keyframes, keyframe, namespace, counter, supports, document, fontfeature, viewport, region
 * @param  {array} [rules=[]]             - Array of CSSRules to search
 * @param  {function} [predecate=Boolean] - Predecate function to filter matches
 * @return {array} Array of matching CSSRules
 * @private
 */

function getDeclarations() {
	var typeName = arguments.length <= 0 || arguments[0] === undefined ? 'style' : arguments[0];
	var rules = arguments.length <= 1 || arguments[1] === undefined ? [] : arguments[1];
	var predecate = arguments.length <= 2 || arguments[2] === undefined ? Boolean : arguments[2];

	// Get target type enum
	var type = _cssruleEnumerations2['default'][typeName];

	return (0, _toArray2['default'])(rules)
	// filter by rule type
	.filter(function (rule) {
		return rule.type === type;
	})
	// filter with user-provided predecate
	.filter(predecate)
	// unwrap cssRules
	.map(function (rule) {
		return rule.cssRules;
	})
	// flatten cssRules
	.reduce(function (results, cssRules) {
		return [].concat(_toConsumableArray(results), _toConsumableArray((0, _toArray2['default'])(cssRules)));
	}, []);
}

module.exports = exports['default'];