'use strict';

Object.defineProperty(exports, '__esModule', {
	value: true
});
exports['default'] = getKeyframes;
// istanbul ignore next

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

// istanbul ignore next

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) arr2[i] = arr[i]; return arr2; } else { return Array.from(arr); } }

var _toArray = require('./to-array');

var _toArray2 = _interopRequireDefault(_toArray);

var _getCssRules = require('./get-css-rules');

var _getCssRules2 = _interopRequireDefault(_getCssRules);

var _getKeyframeDeclarations = require('./get-keyframe-declarations');

var _getKeyframeDeclarations2 = _interopRequireDefault(_getKeyframeDeclarations);

var _transformKeyframeDeclaration = require('./transform-keyframe-declaration');

var _transformKeyframeDeclaration2 = _interopRequireDefault(_transformKeyframeDeclaration);

/**
 * Gets webanimation keyframes attached to a CSS animationName
 * @param {string} animationName - CSS animationName to search keyframes for
 * @param {Window} [window=global.window] - Global context to use
 * @param {Document} [document=global.window] - Document context to use
 * @return {array} Array of webanimation keyframes attached to animationName
 * @private
 */

function getKeyframes(animationName) {
	var window = arguments.length <= 1 || arguments[1] === undefined ? global.window : arguments[1];
	var document = arguments.length <= 2 || arguments[2] === undefined ? global.document : arguments[2];

	// Collect CSSRules present in the document
	var CSSRules = (0, _toArray2['default'])(document.styleSheets).reduce(function (results, styleSheet) {
		return [].concat(_toConsumableArray(results), _toConsumableArray((0, _getCssRules2['default'])(styleSheet)));
	}, []);

	// Filter CSSRules for KeyFrameRules
	return (0, _getKeyframeDeclarations2['default'])(animationName, CSSRules)
	// Transform KeyFrameRules to web animation compatible format
	.map(_transformKeyframeDeclaration2['default'])
	// Flatten mulitdimensional array of transformed keyframes
	.reduce(function (results, declaration) {
		var amend = Array.isArray(declaration) ? declaration : [declaration];
		return [].concat(_toConsumableArray(results), _toConsumableArray(amend));
	}, []);
}

module.exports = exports['default'];