'use strict';

Object.defineProperty(exports, '__esModule', {
	value: true
});
// istanbul ignore next

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports['default'] = getPlayer;
// istanbul ignore next

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _getVendorPrefix = require('./get-vendor-prefix');

var _getKeyframes = require('./get-keyframes');

var _getKeyframes2 = _interopRequireDefault(_getKeyframes);

var _getAnimationProperties2 = require('./get-animation-properties');

var _getAnimationProperties3 = _interopRequireDefault(_getAnimationProperties2);

var _convertAnimationDuration = require('./convert-animation-duration');

var _convertAnimationDuration2 = _interopRequireDefault(_convertAnimationDuration);

var _convertAnimationIterations = require('./convert-animation-iterations');

var _convertAnimationIterations2 = _interopRequireDefault(_convertAnimationIterations);

/**
 * Gets a web animation player based on the currently assigned CSS animation
 * @param element {HTMLElement} DOM element to scan for an applied CSS animation
 * @param settings {object} Settings object passed to JogWheel instance
 * @param window {Window} [window=global.window] Global context to use
 * @param document {Document} [document=global.window] Document context to use
 * @return {Object} `player` and `duration` attached to element
 * @private
 */

function getPlayer(element, settings) {
	var window = arguments.length <= 2 || arguments[2] === undefined ? global.window : arguments[2];
	var document = arguments.length <= 3 || arguments[3] === undefined ? global.document : arguments[3];

	// Read all animation related styles from element, respect prefixes

	var _getAnimationProperties = (0, _getAnimationProperties3['default'])(element, window, document);

	var name = _getAnimationProperties.name;
	var duration = _getAnimationProperties.duration;
	var iterationCount = _getAnimationProperties.iterationCount;
	var timingFunction = _getAnimationProperties.timingFunction;
	var fillMode = _getAnimationProperties.fillMode;
	var playState = _getAnimationProperties.playState;

	// Generate keyframes based on the assigned animationName
	var keyframes = (0, _getKeyframes2['default'])(name, window, document);

	// TODO: Should bail/stub? here if no keyframes are found
	// Construct options for the webanimation player instance
	var options = _extends({
		duration: (0, _convertAnimationDuration2['default'])(duration),
		iterations: (0, _convertAnimationIterations2['default'])(iterationCount),
		fill: fillMode,
		easing: timingFunction,
		playState: playState
	}, settings);

	// TODO: Test get-keyframes for sorting and duplication
	// Sort by offset and remove duplicates
	keyframes.sort(function (a, b) {
		return a.offset - b.offset;
	});

	// Use user-provided animate function (ponyfill) or HTMLElement.prototype.animate
	var animate = settings.animate ? function () {
		for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
			args[_key] = arguments[_key];
		}

		return settings.animate.apply(settings, [element].concat(args));
	} : element.animate;

	if (typeof animate !== 'function') {
		console.warn('No animation function found. Have you forgotten to include a pony- or polyfill?');
	}

	// Construct webanimation player instance with keyframes and options
	var player = animate.bind(element)(keyframes, options);

	// Detach the former animation to prevent problems with polyfill
	element.style[(0, _getVendorPrefix.prefix)('animationName', window, document)] = '__jogwheelName-' + name;
	player.__jogwheelName = name;

	// Pause or play the webanimation player instance based on CSS animationPlayState
	if (options.playState === 'paused') {
		player.pause();
	} else {
		player.play();
	}

	return {
		player: player,
		duration: options.duration
	};
}

module.exports = exports['default'];