'use strict';

Object.defineProperty(exports, '__esModule', {
	value: true
});
exports['default'] = getVendorPrefix;
exports.prefix = prefix;
var cacheKey = '__jogwheel_vendor_prefix_cache';

/**
 * Gets the primary CSS vendor prefix for the current or provided document environment
 * @param  {Window} [window = global.window] The window context to use
 * @param  {Document} [document = global.document] The document context to use
 * @return {string} The primary CSS vendor prefix
 * @private
 */

function getVendorPrefix() {
	var window = arguments.length <= 0 || arguments[0] === undefined ? global.window : arguments[0];
	var document = arguments.length <= 1 || arguments[1] === undefined ? global.document : arguments[1];

	// Replace this when we get WeakMaps
	if (document[cacheKey]) {
		return document[cacheKey];
	}

	document[cacheKey] = '';

	var prefixes = /^(Moz|Webkit|ms)(?=[A-Z])/i;
	var element = document.body;

	for (var property in element.style) {
		// eslint-disable-line guard-for-in
		if (prefixes.test(property)) {
			document[cacheKey] = property.match(prefixes)[0];
			return document[cacheKey];
		}
	}

	return document[cacheKey];
}

/**
 * Prefixes a given CSS property if needed in the current or provided document environment
 * @param  {string} propertyName CSS property to prefix
 * @param  {Window} [window = global.window] The window context to use
 * @param  {Document} [document = global.document] The document context to use
 * @return {string} The prefixed version of the CSS property
 * @private
 */

function prefix(propertyName) {
	var window = arguments.length <= 1 || arguments[1] === undefined ? global.window : arguments[1];
	var document = arguments.length <= 2 || arguments[2] === undefined ? global.document : arguments[2];

	var element = document.body;
	var prefix = getVendorPrefix(window, document);

	if (prefix === '') {
		return propertyName;
	}

	if (propertyName in element.style) {
		return propertyName;
	}

	return '' + prefix + propertyName[0].toUpperCase() + propertyName.slice(1);
}