'use strict';

Object.defineProperty(exports, '__esModule', {
	value: true
});
// istanbul ignore next
var _bind = Function.prototype.bind;
// istanbul ignore next

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

// istanbul ignore next

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

// istanbul ignore next

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

// istanbul ignore next

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

var _defaultsJs = require('./defaults.js');

var _defaultsJs2 = _interopRequireDefault(_defaultsJs);

var _getPlayerJs = require('./get-player.js');

var _getPlayerJs2 = _interopRequireDefault(_getPlayerJs);

var JogWheel = (function () {
	_createClass(JogWheel, null, [{
		key: 'create',

		/**
   * Creates a new JogWheel instance
   * @constructor
   * @param  {HTMLElement} element  HTMLElement to instantiate on
   * @param  {object} options Options object
   * @param  {Window} [window=global.window] Global context to use
   * @param  {Document} [document=global.window] Document context to use
   * @return {JogWheel} JogWheel instance
   * @example
   * import JogWheel from 'jogwheel';
   * const element = document.querySelector('[data-animated]');
   *
   * // Instantiate a paused JogWheel instance on element
   * const wheel = JogWheel.create(element, {
   * 	paused: true
   * });
   *
   * // Seek to middle of animation sequence
   * wheel.seek(0.5);
   *
   * // Play the animation
   * wheel.play();
   */
		value: function create() {
			for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
				args[_key] = arguments[_key];
			}

			return new (_bind.apply(JogWheel, [null].concat(args)))();
		}

		/**
   * Creates a new JogWheel instance
   * @constructor
   * @param  {Node|NodeList} nodes  Node or NodeList to instantiate on
   * @param  {object} options Options object
   * @param  {Window} [window=global.window] Global context to use
   * @param  {Document} [document=global.window] Document context to use
   * @return {JogWheel} JogWheel instance
   * @example
   * import JogWheel from 'jogwheel';
   * const element = document.querySelector('[data-animated]');
   *
   * // Instantiate a JogWheel instance on element
   * const wheel = new JogWheel(element);
   */
	}]);

	function JogWheel(nodes, options) {
		var window = arguments.length <= 2 || arguments[2] === undefined ? global.window : arguments[2];
		var document = arguments.length <= 3 || arguments[3] === undefined ? global.document : arguments[3];

		_classCallCheck(this, JogWheel);

		if (!nodes) {
			throw new Error('Could not construct JogWheel, missing element');
		}

		var settings = _extends({}, _defaultsJs2['default'], options);

		var elements = nodes instanceof window.NodeList ? [].slice.call(nodes) : [nodes]; // eslint-disable-line prefer-reflect
		var configurations = elements.map(function (element) {
			return (0, _getPlayerJs2['default'])(element, settings, window, document);
		});
		var players = configurations.map(function (configuration) {
			return configuration.player;
		});
		var durations = configurations.map(function (configuration) {
			return configuration.duration;
		});

		this.__instance = {
			elements: elements, players: players, durations: durations, settings: settings
		};
	}

	/**
  * @readonly
  * @return {string} playState, either `running` or `paused`
  */

	_createClass(JogWheel, [{
		key: 'play',

		/**
   * Plays the animation
   * @return {JogWheel} JogWheel instance
   * @example
   * import JogWheel from 'jogwheel';
   * const element = document.querySelector('[data-animated]');
   *
   * // Instantiate a paused JogWheel instance on element
   * const wheel = JogWheel.create(element, {
   * 	paused: true
   * });
   *
   * // Seek to middle of animation sequence and play
   * wheel.seek(0.5).play();
   */
		value: function play() {
			this.players.forEach(function (player) {
				return player.play();
			});
			return this;
		}

		/**
   * Pauses the animation
   * @return {JogWheel} JogWheel instance
   * @example
   * import JogWheel from 'jogwheel';
   * const element = document.querySelector('[data-animated]');
   *
   * // Instantiate a paused JogWheel instance on element
   * const wheel = JogWheel.create(element, {
   * 	paused: false
   * });
   *
   * // Pause the animation and reset it to animation start
   * wheel.pause().seek(0);
   */
	}, {
		key: 'pause',
		value: function pause() {
			this.players.forEach(function (player) {
				return player.pause();
			});
			return this;
		}

		/**
   * Seeks the timeline of the animation
   * @param  {float} progress fraction of the animation timeline [0..1]
   * @return {JogWheel} JogWheel instance
   * @example
   * import JogWheel from 'jogwheel';
   * const element = document.querySelector('[data-animated]');
   *
   * // Instantiate a paused JogWheel instance on element
   * const wheel = JogWheel.create(element, {
   * 	paused: true
   * });
   *
   * // Keep track of scroll position
   * let scrollTop = document.scrollTop;
   * document.addEventListener('scroll', () => scrollTop = document.scrollTop);
   *
   * // Seek the animation [0..1] for scroll position of [0..300]
   * function loop() {
   * 	const fraction = Math.max((300 / scrollTop) - 1, 0);
   * 	wheel.seek(fraction);
   * 	window.requestAnimationFrame(loop);
   * }
   *
   * // Start the render loop
   * loop();
   */
	}, {
		key: 'seek',
		value: function seek(progress) {
			// istanbul ignore next

			var _this = this;

			this.__instance.players.forEach(function (player, index) {
				player.currentTime = _this.durations[index] * progress;
			});
			return this;
		}

		/**
   * Reregister all eventListeners and cache entries for this JogWheel instance
   * @return {JogWheel} JogWheel instance
   * @private
  	 * @example
  	 * import JogWheel from 'jogwheel';
  	 * const element = document.querySelector('[data-animated]');
  	 *
  	 * // Instantiate a paused JogWheel instance on element
  	 * const wheel = JogWheel.create(element);
  	 *
  	 * // Attach new styling on the page
  	 * const link = document.createElement('link');
  	 * link.rel = 'stylesheet';
  	 * link.src = 'http://google.com/'
  	 *
  	 * // Unplug and plug again to read new styling information
  	 * wheel.unplug().plug();
  	 */
	}, {
		key: 'plug',
		value: function plug() {
			// TODO: implement this
			// TODO: test this
			return this;
		}

		/**
   * Unregisters all eventListeners and cache entries for this JogWheel instance
   * @return {JogWheel} JogWheel instance
   * @private
   * @example
   * import JogWheel from 'jogwheel';
   * const element = document.querySelector('[data-animated]');
   *
   * // Instantiate a paused JogWheel instance on element
   * const wheel = JogWheel.create(element);
   *
   * // Attach new styling on the page
   * const link = document.createElement('link');
   * link.rel = 'stylesheet';
   * link.src = 'http://google.com/'
   *
   * // Unplug and plug again to read new styling information
   * wheel.unplug().plug();
   */
	}, {
		key: 'unplug',
		value: function unplug() {
			// TODO: implement this
			// TODO: test this
			return this;
		}

		/**
   * Renders inline styles on the instance element if applicable
   * @return {JogWheel} JogWheel instance
   * @private
   */
	}, {
		key: 'render',
		value: function render() {
			// TODO: add documentation
			// TODO: implement this, must proxy element writes for e.g. react integration
			// this.settings.render(this.element, styles);
			return this;
		}
	}, {
		key: 'playState',
		get: function get() {
			// JogWheel does not support asynchronously running animations
			// in one instance, thus fetching the first player is enough
			var player = this.players[0];
			return player.playState;
		}

		/**
   * @readonly
   * @return {float} progress in fraction of 1 [0..1]
   */
	}, {
		key: 'progress',
		get: function get() {
			// JogWheel does not support asynchronously running animations
			// in one instance, thus fetching the first player is enough
			var player = this.players[0];
			var duration = this.durations[0];
			return player.currentTime / duration;
		}

		/**
   * @readonly
   * @return {array} WebAnimationPlayer instances by JogWheel instance
   */
	}, {
		key: 'players',
		get: function get() {
			return this.__instance.players;
		}

		/**
   * @readonly
   * @return {array} durations used by JogWheel instance
   */
	}, {
		key: 'durations',
		get: function get() {
			return this.__instance.durations;
		}
	}]);

	return JogWheel;
})();

exports['default'] = JogWheel;
module.exports = exports['default'];