'use strict';

Object.defineProperty(exports, '__esModule', {
	value: true
});
// istanbul ignore next

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports['default'] = transformKeyframeDeclaration;
// istanbul ignore next

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _parseKeyframeKey = require('./parse-keyframe-key');

var _parseKeyframeKey2 = _interopRequireDefault(_parseKeyframeKey);

var _getDefinedStyles = require('./get-defined-styles');

var _getDefinedStyles2 = _interopRequireDefault(_getDefinedStyles);

var _removeVendorPrefix = require('./remove-vendor-prefix');

var _removeVendorPrefix2 = _interopRequireDefault(_removeVendorPrefix);

/**
 * Transforms KeyFrameRule to array of web animation compatible keyframes
 * @param  {Object} keyFrameRule KeyFrameRule to transform
 * @return {Array}               Array of webanimation keyframes
 * @private
 */

function transformKeyframeDeclaration(keyFrameRule) {
	// Convert keyFrame.keyText to integers holding percentage of keyframe
	var percentages = (0, _parseKeyframeKey2['default'])(keyFrameRule.keyText);
	var style = (0, _getDefinedStyles2['default'])(keyFrameRule.style);

	// Normalize to unprefixed styles
	var normalizedStyles = Object.keys(style).reduce(function (result, propertyName) {
		result[(0, _removeVendorPrefix2['default'])(propertyName)] = style[propertyName];
		return result;
	}, {});

	return percentages.map(function (percentage) {
		return _extends({
			// Convert percentage to fraction of 1 for webanimation compat
			offset: percentage / 100
		}, normalizedStyles);
	});
}

module.exports = exports['default'];
// Mixin with extracted keyframe styling